==> spirit_hub-0.0.1.6.tar.gz: spirit_hub-0.0.1.6/spec/factories/tagset_factory.rb <==
# frozen_string_literal: true

require 'faker'

FactoryBot.define do
  factory :tagset_directory, class: 'Tagset' do
    sequence(:title) { |n| "Tagset Title #{n}" }
    last_current_user_name { %w[Jean Paul Jacques Sophie].sample }
    end_date { Date.today + rand(1..30) }
    type { 'directory' }
    labels { ['hubdoc'] }
    operation_id { '123456' }
    cycle { SpiritHub::HubdocCycle.default_cycle }

    trait :with_logs do
      after(:create) do |tagset|
        tagset.logs.create(action: 'Crée', user_id: tagset.responsible)
        20.times do
          tagset.logs.create(action: 'Modifier', user_id: tagset.responsible)
        end
      end
    end

    trait :complete do
      content_completeness { 100 }
      current_state { 'Complet' }
    end

    trait :incomplete do
      content_completeness { rand(99) }
      current_state { 'À completer' }
    end
  end

  factory :tagset_doc, class: 'Tagset' do
    sequence(:title) { |n| "Doc Title #{n}" }
    end_date { Date.today + rand(1..30) }
    type { 'document' }
    labels { ['hubdoc'] }
    operation_id { '123456' }
    cycle { SpiritHub::HubdocCycle.default_cycle }

    trait :with_file do
      transient do
        filename {  'dog.jpg' }
      end

      after(:create) do |tagset, evaluator|
        file_path = Rails.root.join("packages/spirit_hub/spec/fixtures/files/#{evaluator.filename}")
        uploaded_file = ActionDispatch::Http::UploadedFile.new(
          tempfile: File.open(file_path, 'rb'),
          filename: File.basename(file_path),
          type: 'application/pdf'
        )
        tagset.add_doc_to_tagset_doc(uploaded_file, tagset.responsible && User.find(tagset.responsible))

        DocPreviewWorker.new.perform(tagset.doc_ids.last)
        tagset.save
      end
    end

    trait :with_informed do
      after(:create) do |tagset|
        users = FactoryBot.create_list(:user, rand(1..5))
        tagset.update(informed: users.map(&:id))
      end
    end

    trait :with_logs do
      after(:create) do |tagset|
        tagset.logs.create(action: 'Crée', user_id: tagset.responsible)
        20.times do
          tagset.logs.create(action: 'Modifier', user_id: tagset.responsible)
        end
      end
    end

    trait :with_state do
      transient do
        state_key { :classify }
      end
      after(:create) do |tagset, evaluator|
        SpiritHub::HubdocCycle.change_state(tagset, evaluator.state_key, User.all.sample)
        tagset.save
      end
    end
  end
end

==> spirit_hub-0.0.1.7.tar.gz: spirit_hub-0.0.1.7/spec/factories/tagset_factory.rb <==
# frozen_string_literal: true

require 'faker'

FactoryBot.define do
  factory :tagset_directory, class: 'Tagset' do
    sequence(:title) { |n| "Tagset Title #{n}" }
    last_current_user_name { %w[Jean Paul Jacques Sophie].sample }
    end_date { Date.today + rand(1..30) }
    type { 'directory' }
    labels { ['hubdoc'] }
    operation_id { '123456' }
    cycle { SpiritHub::HubdocCycle.default_cycle }

    trait :with_logs do
      after(:create) do |tagset|
        tagset.logs.create(action: 'Crée', user_id: tagset.responsible, data: 'hubdoc')
        20.times do
          tagset.logs.create(action: 'Modifier', user_id: tagset.responsible, data: 'hubdoc')
        end
      end
    end

    trait :complete do
      content_completeness { 100 }
      current_state { 'Complet' }
    end

    trait :incomplete do
      content_completeness { rand(99) }
      current_state { 'À completer' }
    end
  end

  factory :tagset_doc, class: 'Tagset' do
    sequence(:title) { |n| "Doc Title #{n}" }
    end_date { Date.today + rand(1..30) }
    type { 'document' }
    labels { ['hubdoc'] }
    operation_id { '123456' }
    cycle { SpiritHub::HubdocCycle.default_cycle }

    trait :with_files do
      transient do
        filenames { ['dog.jpg'] }
      end

      after(:create) do |tagset, evaluator|
        uploaded_files = evaluator.filenames.map do |filename|
          file_path = Rails.root.join("packages/spirit_hub/spec/fixtures/files/#{filename}")

          ActionDispatch::Http::UploadedFile.new(
            tempfile: File.open(file_path, 'rb'),
            filename: File.basename(file_path),
            type: 'application/pdf'
          )
        end

        tagset.add_doc_to_tagset_doc(uploaded_files, tagset.responsible && User.find(tagset.responsible))

        DocPreviewWorker.new.perform(tagset.doc_ids.last)
        tagset.save
      end
    end

    trait :with_file do
      with_files
      filenames { [filename] }

      transient do
        filename { 'dog.jpg' }
      end
    end

    trait :with_informed do
      after(:create) do |tagset|
        users = FactoryBot.create_list(:user, rand(1..5))
        tagset.update(informed: users.map(&:id))
      end
    end

    trait :with_logs do
      after(:create) do |tagset|
        tagset.logs.create(action: 'Crée', user_id: tagset.responsible, data: 'hubdoc')
        20.times do
          tagset.logs.create(action: 'Modifier', user_id: tagset.responsible, data: 'hubdoc')
        end
      end
    end

    trait :with_state do
      transient do
        state_key { :classify }
      end
      after(:create) do |tagset, evaluator|
        SpiritHub::HubdocCycle.change_state(tagset, evaluator.state_key, User.all.sample)
        tagset.save
      end
    end
  end
end
